@@ -27,8 +27,9 @@
 #include "config.h"
 #include "zenity.h"
 #include "util.h"
+#include <string.h>
 #include <gdk/gdkkeysyms.h>
-#include <libgnomecanvas/gnome-canvas.h>
+#include <libgnomecanvas/libgnomecanvas.h>
 #include <glade/glade.h>
 
 #define GTK_RESPONSE_CREDITS 0
@@ -55,8 +56,9 @@ static const gchar *author_credits[] = {
   "John Fleck <jfleck@inkstain.net>",
   "James Henstridge <james@daa.com.au>",
   "Mihai T. Lazarescu <mihai@email.it>",
-  "Mike Newman <mike@gtnorthern.demon.co.uk>",
+  "Mike Newman <mikegtn@gnome.org>",
   "Havoc Pennington <hp@redhat.com>",
+  "Kevin C. Krinke <kckrinke@opendoorsoftware.com>",
   "Kristian Rietveld <kris@gtk.org>",
   "Jakub Steiner <jimmac@ximian.com>",
   "Daniel d'Surreal <dagmar@speakeasy.net>",
@@ -142,7 +144,7 @@ zenity_create_clothes (GtkWidget *canvas_board)
     pixbuf = gdk_pixbuf_new_from_file (pixbuf_path, NULL);
 
     canvas_item = gnome_canvas_item_new (GNOME_CANVAS_GROUP (GNOME_CANVAS (canvas_board)->root),
-                                         gnome_canvas_pixbuf_get_type (),
+                                         GNOME_TYPE_CANVAS_PIXBUF,
                                          "x", monk_clothes[i].x,
                                          "y", monk_clothes[i].y,
                                          "pixbuf", pixbuf,
@@ -158,7 +160,6 @@ zenity_create_monk (void)
 {
   GtkWidget *canvas_board;
   GnomeCanvasItem *canvas_item;
-  GnomeCanvasGroup *root;
   GdkPixbuf *pixbuf;
   GdkColor color = { 0, 0xffff, 0xffff, 0xffff };
 
@@ -177,7 +178,7 @@ zenity_create_monk (void)
   pixbuf = gdk_pixbuf_new_from_file (ZENITY_CLOTHES_PATH "monk.png", NULL);
 
   canvas_item = gnome_canvas_item_new (GNOME_CANVAS_GROUP (GNOME_CANVAS (canvas_board)->root),
-                                       gnome_canvas_pixbuf_get_type (),
+                                       GNOME_TYPE_CANVAS_PIXBUF,
                                        "x", (ZENITY_CANVAS_X / 2.0)/2.0 + 10.0,
                                        "y", (ZENITY_CANVAS_Y / 2.0)/2.0 - 50.0,
                                        "pixbuf", pixbuf,
@@ -257,7 +258,7 @@ zenity_about (ZenityData *data)
   glade_dialog = zenity_util_load_glade_file ("zenity_about_dialog");
 
   if (glade_dialog == NULL) {
-    data->exit_code = -1;
+    data->exit_code = zenity_util_return_exit_code (ZENITY_ERROR);
     return;
   }
 
@@ -368,13 +369,6 @@ zenity_about_update_translator_label (GtkWidget *label)
   g_string_free (string, TRUE);
 }
 
-static void
-zenity_about_dialog_credits_response (GtkWidget *widget, int response, gpointer data)
-{
-  gtk_widget_destroy (widget);
-  widget = NULL;
-}
-
 static void
 zenity_about_display_credits_dialog (void)
 {
@@ -441,7 +435,7 @@ zenity_about_dialog_response (GtkWidget *widget, int response, gpointer data)
 
   switch (response) {
     case GTK_RESPONSE_OK:
-      zen_data->exit_code = 0;
+      zen_data->exit_code = zenity_util_return_exit_code (ZENITY_OK);
       gtk_main_quit ();
       break;
 
@@ -455,7 +449,7 @@ zenity_about_dialog_response (GtkWidget *widget, int response, gpointer data)
 
     default:
       /* Esc dialog */
-      zen_data->exit_code = 1;
+      zen_data->exit_code = zenity_util_return_exit_code (ZENITY_ESC);
       break;
   }
 }
