@@ -22,13 +22,17 @@
  */
 
 #include <stdio.h>
+#include <string.h>
+#include <stdlib.h>
+#include <sys/types.h>
+#include <signal.h>
 #include <glade/glade.h>
 #include "zenity.h"
 #include "util.h"
 
 static guint timer;
 static GladeXML *glade_dialog;
-
+static ZenityData *zen_data;
 static GIOChannel *channel;
 
 gint zenity_progress_timeout (gpointer data);
@@ -97,7 +101,7 @@ zenity_progress_handle_stdin (GIOChannel   *channel,
         /* We have a comment, so let's try to change the label */
         match = g_strstr_len (string->str, strlen (string->str), "#");
         match++;
-        gtk_label_set_text (GTK_LABEL (progress_label), g_strchomp (g_strchug (match)));
+        gtk_label_set_text (GTK_LABEL (progress_label), g_strcompress(g_strchomp (g_strchug (match))));
       } else {
 
         if (!g_ascii_isdigit (*(string->str)))
@@ -111,6 +115,11 @@ zenity_progress_handle_stdin (GIOChannel   *channel,
           gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (progress_bar), 1.0);
 	  gtk_widget_set_sensitive(GTK_WIDGET (button), TRUE);
 	  gtk_widget_grab_focus(GTK_WIDGET (button));
+	  if (progress_data->autoclose) {
+		zen_data->exit_code = zenity_util_return_exit_code (ZENITY_OK);
+		gtk_main_quit();
+		
+	  }
 	} else
           gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (progress_bar), percentage / 100.0);
       }
@@ -163,12 +172,12 @@ zenity_progress (ZenityData *data, ZenityProgressData *progress_data)
   GtkWidget *dialog;
   GtkWidget *text;
   GtkWidget *progress_bar;
-  guint input;
 
+  zen_data = data;
   glade_dialog = zenity_util_load_glade_file ("zenity_progress_dialog");
 
   if (glade_dialog == NULL) {
-    data->exit_code = -1;
+    data->exit_code = zenity_util_return_exit_code (ZENITY_ERROR);
     return;
   }
 	
@@ -207,11 +216,9 @@ zenity_progress (ZenityData *data, ZenityProgressData *progress_data)
 static void
 zenity_progress_dialog_response (GtkWidget *widget, int response, gpointer data)
 {
-  ZenityData *zen_data = data;
-
   switch (response) {
     case GTK_RESPONSE_OK:
-      zen_data->exit_code = 0;
+      zen_data->exit_code = zenity_util_return_exit_code (ZENITY_OK);
       gtk_main_quit ();
       break;
 		
@@ -221,13 +228,13 @@ zenity_progress_dialog_response (GtkWidget *widget, int response, gpointer data)
        * stuff. Should be using SIGHUP instead of 1 though.
        */
       kill (getpid (), 1);
-      zen_data->exit_code = 1;
+      zen_data->exit_code = zenity_util_return_exit_code (ZENITY_CANCEL);
       gtk_main_quit ();
       break;
   
     default:
       /* Esc dialog */
-      zen_data->exit_code = 1;
+      zen_data->exit_code = zenity_util_return_exit_code (ZENITY_ESC);
       break;
   }
 }
